@@ -1,10 +1,10 @@
-import flatbread.core.select
-import flatbread.core.axes.define
-import flatbread.core.aggregation.totals
+from flatbread.core.select import columns as select_columns
+from flatbread.core.axes import define
+from flatbread.core.aggregation import totals
 
 
 def select(df, columns):
-    return flatbread.core.select.columns(df, columns)
+    return select_columns(df, columns)
 
 
 def normalize(df, func=None):
@@ -17,17 +17,17 @@ def normalize(df, func=None):
 
 
 def rename(df, mapper, level=0):
-    return flatbread.core.axes.define.rename(df, mapper, axis=1, level=level)
+    return define.rename(df, mapper, axis=1, level=level)
 
 
 def order(df, column, categories):
     df = df.copy()
-    df[column] = flatbread.core.axes.define.order_categories(df[column], categories)
+    df[column] = define.order_categories(df[column], categories)
     return df
 
 
 def add_level(df, level_name, level):
-    return flatbread.core.axes.define.add_idx_level(
+    return define.add_idx_level(
         df, level_name,
         axis=1,
         level=level
@@ -35,4 +35,4 @@ def add_level(df, level_name, level):
 
 
 def totals(df, level=0):
-    return flatbread.core.aggregation.totals.add(df, axis=1, level=level, **kwargs)
+    return totals.add(df, axis=1, level=level, **kwargs)
